import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.Stroke;
import java.io.PrintStream;

/** An ellipse that may be drawn on the canvas. */
public class EllipseShape implements Shape {
	private Color  color;
	private Stroke stroke;
	private int    left;
	private int 	top;
	private int    width;
	private int    height;

	public EllipseShape(Color c, Stroke s, java.awt.Point p1, java.awt.Point p2) {
		color = c;
		stroke = s;
		
		// ellipse parameters
		left       = Math.min(p1.x, p2.x);
		int right  = Math.max(p1.x, p2.x);
		top        = Math.min(p1.y, p2.y);
		int bottom = Math.max(p1.y, p2.y);
		  
		width  = (right-left);
		height = (bottom-top);
		
	}
	
	 /** Construct an ellipse, given its color, line thickness, 
		 upper left corner (l0,t0), width w0 and height t0.

  	    The constructor assumes that all parameters are nonnull.
	 */
	public EllipseShape(Color c, Stroke s, int l0, int t0, int w0, int h0) {
		color  = c;
		stroke = s;
		left   = l0;
		top    = t0; 
		width  = w0;
		height = h0;
		
	}
	
	public void draw(Graphics2D gc) {
		gc.setColor(color);
		gc.setStroke(stroke);
		gc.drawOval(left, top, width, height);

	}
	
}
